==> bot4j-2.0.0-sources.jar: cn/blankcat/openapi/v1/service/MessageReactionService.java <==
package cn.blankcat.openapi.v1.service;

import cn.blankcat.dto.message.Message;
import cn.blankcat.dto.pager.MessageReactionPager;
import cn.blankcat.openapi.v1.Resource;
import retrofit2.Call;
import retrofit2.http.*;

public interface MessageReactionService{

    // CreateMessageReaction 对消息发表表情表态
    @PUT(Resource.messageReactionURI)
    Call<String> createMessageReaction(@Path("channel_id") String channelId,
                                       @Path("message_id") String messageId,
                                       @Path("emoji_type") Integer emojiType,
                                       @Path("emoji_id") String emojiId);

    // DeleteOwnMessageReaction 删除自己的消息表情表态
    @DELETE(Resource.messageReactionURI)
    Call<String> deleteOwnMessageReaction(@Path("channel_id") String channelId,
                                          @Path("message_id") String messageId,
                                          @Path("emoji_type") Integer emojiType,
                                          @Path("emoji_id") String emojiId);

    // GetMessageReactionUsers 获取消息表情表态用户列表
    @GET(Resource.messageReactionURI)
    Call<Message> getMessageReactionUsers(@Path("channel_id") String channelId,
                                          @Path("message_id") String messageId,
                                          @Path("emoji_type") Integer emojiType,
                                          @Path("emoji_id") String emojiId,
                                          @QueryMap MessageReactionPager pager);


}

==> bot4j-2.0.1-sources.jar: cn/blankcat/openapi/v1/service/MessageReactionService.java <==
package cn.blankcat.openapi.v1.service;

import cn.blankcat.dto.message.Message;
import cn.blankcat.openapi.v1.Resource;
import retrofit2.Call;
import retrofit2.http.*;

import java.util.Map;

public interface MessageReactionService{

    // CreateMessageReaction 对消息发表表情表态
    @PUT(Resource.messageReactionURI)
    Call<String> createMessageReaction(@Path("channel_id") String channelId,
                                       @Path("message_id") String messageId,
                                       @Path("emoji_type") Integer emojiType,
                                       @Path("emoji_id") String emojiId);

    // DeleteOwnMessageReaction 删除自己的消息表情表态
    @DELETE(Resource.messageReactionURI)
    Call<String> deleteOwnMessageReaction(@Path("channel_id") String channelId,
                                          @Path("message_id") String messageId,
                                          @Path("emoji_type") Integer emojiType,
                                          @Path("emoji_id") String emojiId);

    // GetMessageReactionUsers 获取消息表情表态用户列表
    @GET(Resource.messageReactionURI)
    Call<Message> getMessageReactionUsers(@Path("channel_id") String channelId,
                                          @Path("message_id") String messageId,
                                          @Path("emoji_type") Integer emojiType,
                                          @Path("emoji_id") String emojiId,
                                          @QueryMap Map<String,String> pager);


}
